AutomatedBackupPolicy class

Message describing the user-specified automated backup policy.

All fields in the automated backup policy are optional. Defaults for each field are provided if they are not set.

Constructors

AutomatedBackupPolicy({bool? enabled, AutomatedBackupPolicy_WeeklySchedule? weeklySchedule, Duration? backupWindow, AutomatedBackupPolicy_TimeBasedRetention? timeBasedRetention, AutomatedBackupPolicy_QuantityBasedRetention? quantityBasedRetention, String? location, Map<String, String>? labels, EncryptionConfig? encryptionConfig})
factory
AutomatedBackupPolicy.fromBuffer(List<int> i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory
AutomatedBackupPolicy.fromJson(String i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory

Properties

backupWindow ↔ Duration
The length of the time window during which a backup can be taken. If a backup does not succeed within this time window, it will be canceled and considered failed.
getter/setter pair
enabled ↔ bool
Whether automated automated backups are enabled. If not set, defaults to true.
getter/setter pair
encryptionConfig ↔ EncryptionConfig
Optional. The encryption config can be specified to encrypt the backups with a customer-managed encryption key (CMEK). When this field is not specified, the backup will then use default encryption scheme to protect the user data.
getter/setter pair
hashCode → int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
info_ → BuilderInfo
no setter
isFrozen → bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
labels → Map<String, String>
Labels to apply to backups created using this configuration.
no setter
location ↔ String
The location where the backup will be stored. Currently, the only supported option is to store the backup in the same region as the cluster.
getter/setter pair
quantityBasedRetention ↔ AutomatedBackupPolicy_QuantityBasedRetention
Quantity-based Backup retention policy to retain recent backups.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timeBasedRetention ↔ AutomatedBackupPolicy_TimeBasedRetention
Time-based Backup retention policy.
getter/setter pair
unknownFields → UnknownFieldSet
no setterinherited
weeklySchedule ↔ AutomatedBackupPolicy_WeeklySchedule
Weekly schedule for the Backup.
getter/setter pair

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearBackupWindow() → void
clearEnabled() → void
clearEncryptionConfig() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearLocation() → void
clearQuantityBasedRetention() → void
clearRetention() → void
clearSchedule() → void
clearTimeBasedRetention() → void
clearWeeklySchedule() → void
clone() → AutomatedBackupPolicy
Creates a deep copy of the fields in this message. (The generated code uses mergeFromMessage.)
copyWith(void updates(AutomatedBackupPolicy)) → AutomatedBackupPolicy
Apply updates to a copy of this message.
createEmptyInstance() → AutomatedBackupPolicy
Creates an empty instance of the same message type as this.
ensureBackupWindow() → Duration
ensureEncryptionConfig() → EncryptionConfig
ensureQuantityBasedRetention() → AutomatedBackupPolicy_QuantityBasedRetention
ensureTimeBasedRetention() → AutomatedBackupPolicy_TimeBasedRetention
ensureWeeklySchedule() → AutomatedBackupPolicy_WeeklySchedule
extensionsAreInitialized() → bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) → int?
inherited
hasBackupWindow() → bool
hasEnabled() → bool
hasEncryptionConfig() → bool
hasExtension(Extension extension) → bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) → bool
Whether this message has a field associated with tagNumber.
inherited
hasLocation() → bool
hasQuantityBasedRetention() → bool
hasRequiredFields() → bool
Whether the message has required fields.
inherited
hasTimeBasedRetention() → bool
hasWeeklySchedule() → bool
isInitialized() → bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() → String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() → String
Returns a String representation of this message.
inherited
whichRetention() → AutomatedBackupPolicy_Retention
whichSchedule() → AutomatedBackupPolicy_Schedule
writeToBuffer() → Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() → String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() → Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited