Job class

The Cloud Batch Job description.

Constructors

Job({String? name, String? uid, Int64? priority, Iterable<TaskGroup>? taskGroups, AllocationPolicy? allocationPolicy, Map<String, String>? labels, JobStatus? status, Timestamp? createTime, Timestamp? updateTime, LogsPolicy? logsPolicy, Iterable<JobNotification>? notifications})
factory
Job.fromBuffer(List<int> i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory
Job.fromJson(String i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory

Properties

allocationPolicy ↔ AllocationPolicy
Compute resource allocation for all TaskGroups in the Job.
getter/setter pair
createTime ↔ Timestamp
Output only. When the Job was created.
getter/setter pair
hashCode → int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
info_ → BuilderInfo
no setter
isFrozen → bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
labels → Map<String, String>
Labels for the Job. Labels could be user provided or system generated. For example, "labels": { "department": "finance", "environment": "test" } You can assign up to 64 labels. Google Compute Engine label restrictions apply. Label names that start with "goog-" or "google-" are reserved.
no setter
logsPolicy ↔ LogsPolicy
Log preservation policy for the Job.
getter/setter pair
name ↔ String
Output only. Job name. For example: "projects/123456/locations/us-central1/jobs/job01".
getter/setter pair
notifications → List<JobNotification>
Notification configurations.
no setter
priority ↔ Int64
Priority of the Job. The valid value range is [0, 100). Default value is 0. Higher value indicates higher priority. A job with higher priority value is more likely to run earlier if all other requirements are satisfied.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ JobStatus
Output only. Job status. It is read only for users.
getter/setter pair
taskGroups → List<TaskGroup>
Required. TaskGroups in the Job. Only one TaskGroup is supported now.
no setter
uid ↔ String
Output only. A system generated unique ID (in UUID4 format) for the Job.
getter/setter pair
unknownFields → UnknownFieldSet
no setterinherited
updateTime ↔ Timestamp
Output only. The last time the Job was updated.
getter/setter pair

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearAllocationPolicy() → void
clearCreateTime() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearLogsPolicy() → void
clearName() → void
clearPriority() → void
clearStatus() → void
clearUid() → void
clearUpdateTime() → void
clone() → Job
Creates a deep copy of the fields in this message. (The generated code uses mergeFromMessage.)
copyWith(void updates(Job)) → Job
Apply updates to a copy of this message.
createEmptyInstance() → Job
Creates an empty instance of the same message type as this.
ensureAllocationPolicy() → AllocationPolicy
ensureCreateTime() → Timestamp
ensureLogsPolicy() → LogsPolicy
ensureStatus() → JobStatus
ensureUpdateTime() → Timestamp
extensionsAreInitialized() → bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) → int?
inherited
hasAllocationPolicy() → bool
hasCreateTime() → bool
hasExtension(Extension extension) → bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) → bool
Whether this message has a field associated with tagNumber.
inherited
hasLogsPolicy() → bool
hasName() → bool
hasPriority() → bool
hasRequiredFields() → bool
Whether the message has required fields.
inherited
hasStatus() → bool
hasUid() → bool
hasUpdateTime() → bool
isInitialized() → bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() → String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() → String
Returns a String representation of this message.
inherited
writeToBuffer() → Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() → String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() → Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

create() → Job
createRepeated() → PbList<Job>
getDefault() → Job