TaskGroup class

A TaskGroup defines one or more Tasks that all share the same TaskSpec.

Constructors

TaskGroup({String? name, TaskSpec? taskSpec, Int64? taskCount, Int64? parallelism, TaskGroup_SchedulingPolicy? schedulingPolicy, Iterable<Environment>? taskEnvironments, Int64? taskCountPerNode, bool? requireHostsFile, bool? permissiveSsh})
factory
TaskGroup.fromBuffer(List<int> i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory
TaskGroup.fromJson(String i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory

Properties

hashCode → int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
info_ → BuilderInfo
no setter
isFrozen → bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
name ↔ String
Output only. TaskGroup name. The system generates this field based on parent Job name. For example: "projects/123456/locations/us-west1/jobs/job01/taskGroups/group01".
getter/setter pair
parallelism ↔ Int64
Max number of tasks that can run in parallel. Default to min(task_count, 1000). Field parallelism must be 1 if the scheduling_policy is IN_ORDER.
getter/setter pair
permissiveSsh ↔ bool
When true, Batch will configure SSH to allow passwordless login between VMs running the Batch tasks in the same TaskGroup.
getter/setter pair
requireHostsFile ↔ bool
When true, Batch will populate a file with a list of all VMs assigned to the TaskGroup and set the BATCH_HOSTS_FILE environment variable to the path of that file. Defaults to false.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schedulingPolicy ↔ TaskGroup_SchedulingPolicy
Scheduling policy for Tasks in the TaskGroup. The default value is AS_SOON_AS_POSSIBLE.
getter/setter pair
taskCount ↔ Int64
Number of Tasks in the TaskGroup. Default is 1.
getter/setter pair
taskCountPerNode ↔ Int64
Max number of tasks that can be run on a VM at the same time. If not specified, the system will decide a value based on available compute resources on a VM and task requirements.
getter/setter pair
taskEnvironments → List<Environment>
An array of environment variable mappings, which are passed to Tasks with matching indices. If task_environments is used then task_count should not be specified in the request (and will be ignored). Task count will be the length of task_environments.
no setter
taskSpec ↔ TaskSpec
Required. Tasks in the group share the same task spec.
getter/setter pair
unknownFields → UnknownFieldSet
no setterinherited

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearName() → void
clearParallelism() → void
clearPermissiveSsh() → void
clearRequireHostsFile() → void
clearSchedulingPolicy() → void
clearTaskCount() → void
clearTaskCountPerNode() → void
clearTaskSpec() → void
clone() → TaskGroup
Creates a deep copy of the fields in this message. (The generated code uses mergeFromMessage.)
copyWith(void updates(TaskGroup)) → TaskGroup
Apply updates to a copy of this message.
createEmptyInstance() → TaskGroup
Creates an empty instance of the same message type as this.
ensureTaskSpec() → TaskSpec
extensionsAreInitialized() → bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) → int?
inherited
hasExtension(Extension extension) → bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) → bool
Whether this message has a field associated with tagNumber.
inherited
hasName() → bool
hasParallelism() → bool
hasPermissiveSsh() → bool
hasRequiredFields() → bool
Whether the message has required fields.
inherited
hasRequireHostsFile() → bool
hasSchedulingPolicy() → bool
hasTaskCount() → bool
hasTaskCountPerNode() → bool
hasTaskSpec() → bool
isInitialized() → bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() → String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() → String
Returns a String representation of this message.
inherited
writeToBuffer() → Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() → String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() → Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

create() → TaskGroup
createRepeated() → PbList<TaskGroup>
getDefault() → TaskGroup