BuildOptions class

Optional arguments to enable specific features of builds.

Constructors

BuildOptions({Iterable<Hash_HashType>? sourceProvenanceHash, BuildOptions_VerifyOption? requestedVerifyOption, BuildOptions_MachineType? machineType, BuildOptions_SubstitutionOption? substitutionOption, BuildOptions_LogStreamingOption? logStreamingOption, Int64? diskSizeGb, String? workerPool, BuildOptions_LoggingMode? logging, Iterable<String>? env, Iterable<String>? secretEnv, Iterable<Volume>? volumes})
factory
BuildOptions.fromBuffer(List<int> i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory
BuildOptions.fromJson(String i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory

Properties

diskSizeGb ↔ Int64
Requested disk size for the VM that runs the build. Note that this is NOT "disk free"; some of the space will be used by the operating system and build utilities. Also note that this is the minimum disk size that will be allocated for the build -- the build may run with a larger disk than requested. At present, the maximum disk size is 1000GB; builds that request more than the maximum are rejected with an error.
getter/setter pair
env → List<String>
A list of global environment variable definitions that will exist for all build steps in this build. If a variable is defined in both globally and in a build step, the variable will use the build step value.
no setter
hashCode → int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
info_ → BuilderInfo
no setter
isFrozen → bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
logging ↔ BuildOptions_LoggingMode
Option to specify the logging mode, which determines where the logs are stored.
getter/setter pair
logStreamingOption ↔ BuildOptions_LogStreamingOption
Option to define build log streaming behavior to Google Cloud Storage.
getter/setter pair
machineType ↔ BuildOptions_MachineType
Compute Engine machine type on which to run the build.
getter/setter pair
requestedVerifyOption ↔ BuildOptions_VerifyOption
Requested verifiability options.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secretEnv → List<String>
A list of global environment variables, which are encrypted using a Cloud Key Management Service crypto key. These values must be specified in the build's Secret. These variables will be available to all build steps in this build.
no setter
sourceProvenanceHash → List<Hash_HashType>
Requested hash for SourceProvenance.
no setter
substitutionOption ↔ BuildOptions_SubstitutionOption
Option to specify behavior when there is an error in the substitution checks.
getter/setter pair
unknownFields → UnknownFieldSet
no setterinherited
volumes → List<Volume>
Global list of volumes to mount for ALL build steps
no setter
workerPool ↔ String
Option to specify a WorkerPool for the build. Format: projects/{project}/locations/{location}/workerPools/{workerPool}
getter/setter pair

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearDiskSizeGb() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearLogging() → void
clearLogStreamingOption() → void
clearMachineType() → void
clearRequestedVerifyOption() → void
clearSubstitutionOption() → void
clearWorkerPool() → void
clone() → BuildOptions
Creates a deep copy of the fields in this message. (The generated code uses mergeFromMessage.)
copyWith(void updates(BuildOptions)) → BuildOptions
Apply updates to a copy of this message.
createEmptyInstance() → BuildOptions
Creates an empty instance of the same message type as this.
extensionsAreInitialized() → bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) → int?
inherited
hasDiskSizeGb() → bool
hasExtension(Extension extension) → bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) → bool
Whether this message has a field associated with tagNumber.
inherited
hasLogging() → bool
hasLogStreamingOption() → bool
hasMachineType() → bool
hasRequestedVerifyOption() → bool
hasRequiredFields() → bool
Whether the message has required fields.
inherited
hasSubstitutionOption() → bool
hasWorkerPool() → bool
isInitialized() → bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() → String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() → String
Returns a String representation of this message.
inherited
writeToBuffer() → Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() → String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() → Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

create() → BuildOptions
createRepeated() → PbList<BuildOptions>
getDefault() → BuildOptions