WorkerPool class

Describes one particular pool of Cloud Dataflow workers to be instantiated by the Cloud Dataflow service in order to perform the computations required by a job. Note that a workflow job may use multiple pools, in order to match the various computational requirements of the various stages of the job.

Constructors

WorkerPool({String? kind, int? numWorkers, Iterable<Package>? packages, DefaultPackageSet? defaultPackageSet, String? machineType, TeardownPolicy? teardownPolicy, int? diskSizeGb, String? diskSourceImage, String? zone, String? onHostMaintenance, Map<String, String>? metadata, AutoscalingSettings? autoscalingSettings, String? diskType, String? network, String? workerHarnessContainerImage, String? subnetwork, int? numThreadsPerWorker, WorkerIPAddressConfiguration? ipConfiguration, Iterable<SdkHarnessContainerImage>? sdkHarnessContainerImages})
factory
WorkerPool.fromBuffer(List<int> i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory
WorkerPool.fromJson(String i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory

Properties

autoscalingSettings ↔ AutoscalingSettings
Settings for autoscaling of this WorkerPool.
getter/setter pair
defaultPackageSet ↔ DefaultPackageSet
The default package set to install. This allows the service to select a default set of packages which are useful to worker harnesses written in a particular language.
getter/setter pair
diskSizeGb ↔ int
Size of root disk for VMs, in GB. If zero or unspecified, the service will attempt to choose a reasonable default.
getter/setter pair
diskSourceImage ↔ String
Fully qualified source image for disks.
getter/setter pair
diskType ↔ String
Type of root disk for VMs. If empty or unspecified, the service will attempt to choose a reasonable default.
getter/setter pair
hashCode → int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
info_ → BuilderInfo
no setter
ipConfiguration ↔ WorkerIPAddressConfiguration
Configuration for VM IPs.
getter/setter pair
isFrozen → bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
kind ↔ String
The kind of the worker pool; currently only harness and shuffle are supported.
getter/setter pair
machineType ↔ String
Machine type (e.g. "n1-standard-1"). If empty or unspecified, the service will attempt to choose a reasonable default.
getter/setter pair
metadata → Map<String, String>
Metadata to set on the Google Compute Engine VMs.
no setter
network ↔ String
Network to which VMs will be assigned. If empty or unspecified, the service will use the network "default".
getter/setter pair
numThreadsPerWorker ↔ int
The number of threads per worker harness. If empty or unspecified, the service will choose a number of threads (according to the number of cores on the selected machine type for batch, or 1 by convention for streaming).
getter/setter pair
numWorkers ↔ int
Number of Google Compute Engine workers in this pool needed to execute the job. If zero or unspecified, the service will attempt to choose a reasonable default.
getter/setter pair
onHostMaintenance ↔ String
The action to take on host maintenance, as defined by the Google Compute Engine API.
getter/setter pair
packages → List<Package>
Packages to be installed on workers.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sdkHarnessContainerImages → List<SdkHarnessContainerImage>
Set of SDK harness containers needed to execute this pipeline. This will only be set in the Fn API path. For non-cross-language pipelines this should have only one entry. Cross-language pipelines will have two or more entries.
no setter
subnetwork ↔ String
Subnetwork to which VMs will be assigned, if desired. Expected to be of the form "regions/REGION/subnetworks/SUBNETWORK".
getter/setter pair
teardownPolicy ↔ TeardownPolicy
Sets the policy for determining when to turndown worker pool. Allowed values are: TEARDOWN_ALWAYS, TEARDOWN_ON_SUCCESS, and TEARDOWN_NEVER. TEARDOWN_ALWAYS means workers are always torn down regardless of whether the job succeeds. TEARDOWN_ON_SUCCESS means workers are torn down if the job succeeds. TEARDOWN_NEVER means the workers are never torn down.
getter/setter pair
unknownFields → UnknownFieldSet
no setterinherited
workerHarnessContainerImage ↔ String
Required. Docker container image that executes the Cloud Dataflow worker harness, residing in Google Container Registry.
getter/setter pair
zone ↔ String
Zone to run the worker pools in. If empty or unspecified, the service will attempt to choose a reasonable default.
getter/setter pair

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearAutoscalingSettings() → void
clearDefaultPackageSet() → void
clearDiskSizeGb() → void
clearDiskSourceImage() → void
clearDiskType() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearIpConfiguration() → void
clearKind() → void
clearMachineType() → void
clearNetwork() → void
clearNumThreadsPerWorker() → void
clearNumWorkers() → void
clearOnHostMaintenance() → void
clearSubnetwork() → void
clearTeardownPolicy() → void
clearWorkerHarnessContainerImage() → void
clearZone() → void
clone() → WorkerPool
Creates a deep copy of the fields in this message. (The generated code uses mergeFromMessage.)
copyWith(void updates(WorkerPool)) → WorkerPool
Apply updates to a copy of this message.
createEmptyInstance() → WorkerPool
Creates an empty instance of the same message type as this.
ensureAutoscalingSettings() → AutoscalingSettings
extensionsAreInitialized() → bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) → int?
inherited
hasAutoscalingSettings() → bool
hasDefaultPackageSet() → bool
hasDiskSizeGb() → bool
hasDiskSourceImage() → bool
hasDiskType() → bool
hasExtension(Extension extension) → bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) → bool
Whether this message has a field associated with tagNumber.
inherited
hasIpConfiguration() → bool
hasKind() → bool
hasMachineType() → bool
hasNetwork() → bool
hasNumThreadsPerWorker() → bool
hasNumWorkers() → bool
hasOnHostMaintenance() → bool
hasRequiredFields() → bool
Whether the message has required fields.
inherited
hasSubnetwork() → bool
hasTeardownPolicy() → bool
hasWorkerHarnessContainerImage() → bool
hasZone() → bool
isInitialized() → bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() → String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() → String
Returns a String representation of this message.
inherited
writeToBuffer() → Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() → String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() → Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

create() → WorkerPool
createRepeated() → PbList<WorkerPool>
getDefault() → WorkerPool