DataQualityRule class

A rule captures data quality intent about a data source.

Constructors

DataQualityRule({DataQualityRule_RangeExpectation? rangeExpectation, DataQualityRule_NonNullExpectation? nonNullExpectation, DataQualityRule_SetExpectation? setExpectation, DataQualityRule_RegexExpectation? regexExpectation, DataQualityRule_UniquenessExpectation? uniquenessExpectation, DataQualityRule_StatisticRangeExpectation? statisticRangeExpectation, DataQualityRule_RowConditionExpectation? rowConditionExpectation, DataQualityRule_TableConditionExpectation? tableConditionExpectation, String? column, bool? ignoreNull, String? dimension, double? threshold})
factory
DataQualityRule.fromBuffer(List<int> i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory
DataQualityRule.fromJson(String i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory

Properties

column ↔ String
Optional. The unnested column which this rule is evaluated against.
getter/setter pair
dimension ↔ String
Required. The dimension a rule belongs to. Results are also aggregated at the dimension level. Supported dimensions are "COMPLETENESS", "ACCURACY", "CONSISTENCY", "VALIDITY", "UNIQUENESS", "INTEGRITY"
getter/setter pair
hashCode → int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
ignoreNull ↔ bool
Optional. Rows with null values will automatically fail a rule, unless ignore_null is true. In that case, such null rows are trivially considered passing.
getter/setter pair
info_ → BuilderInfo
no setter
isFrozen → bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
nonNullExpectation ↔ DataQualityRule_NonNullExpectation
ColumnMap rule which evaluates whether each column value is null.
getter/setter pair
rangeExpectation ↔ DataQualityRule_RangeExpectation
ColumnMap rule which evaluates whether each column value lies between a specified range.
getter/setter pair
regexExpectation ↔ DataQualityRule_RegexExpectation
ColumnMap rule which evaluates whether each column value matches a specified regex.
getter/setter pair
rowConditionExpectation ↔ DataQualityRule_RowConditionExpectation
Table rule which evaluates whether each row passes the specified condition.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
setExpectation ↔ DataQualityRule_SetExpectation
ColumnMap rule which evaluates whether each column value is contained by a specified set.
getter/setter pair
statisticRangeExpectation ↔ DataQualityRule_StatisticRangeExpectation
ColumnAggregate rule which evaluates whether the column aggregate statistic lies between a specified range.
getter/setter pair
tableConditionExpectation ↔ DataQualityRule_TableConditionExpectation
Table rule which evaluates whether the provided expression is true.
getter/setter pair
threshold ↔ double
Optional. The minimum ratio of passing_rows / total_rows required to pass this rule, with a range of 0.0, 1.0.
getter/setter pair
uniquenessExpectation ↔ DataQualityRule_UniquenessExpectation
ColumnAggregate rule which evaluates whether the column has duplicates.
getter/setter pair
unknownFields → UnknownFieldSet
no setterinherited

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearColumn() → void
clearDimension() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearIgnoreNull() → void
clearNonNullExpectation() → void
clearRangeExpectation() → void
clearRegexExpectation() → void
clearRowConditionExpectation() → void
clearRuleType() → void
clearSetExpectation() → void
clearStatisticRangeExpectation() → void
clearTableConditionExpectation() → void
clearThreshold() → void
clearUniquenessExpectation() → void
clone() → DataQualityRule
Creates a deep copy of the fields in this message. (The generated code uses mergeFromMessage.)
copyWith(void updates(DataQualityRule)) → DataQualityRule
Apply updates to a copy of this message.
createEmptyInstance() → DataQualityRule
Creates an empty instance of the same message type as this.
ensureNonNullExpectation() → DataQualityRule_NonNullExpectation
ensureRangeExpectation() → DataQualityRule_RangeExpectation
ensureRegexExpectation() → DataQualityRule_RegexExpectation
ensureRowConditionExpectation() → DataQualityRule_RowConditionExpectation
ensureSetExpectation() → DataQualityRule_SetExpectation
ensureStatisticRangeExpectation() → DataQualityRule_StatisticRangeExpectation
ensureTableConditionExpectation() → DataQualityRule_TableConditionExpectation
ensureUniquenessExpectation() → DataQualityRule_UniquenessExpectation
extensionsAreInitialized() → bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) → int?
inherited
hasColumn() → bool
hasDimension() → bool
hasExtension(Extension extension) → bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) → bool
Whether this message has a field associated with tagNumber.
inherited
hasIgnoreNull() → bool
hasNonNullExpectation() → bool
hasRangeExpectation() → bool
hasRegexExpectation() → bool
hasRequiredFields() → bool
Whether the message has required fields.
inherited
hasRowConditionExpectation() → bool
hasSetExpectation() → bool
hasStatisticRangeExpectation() → bool
hasTableConditionExpectation() → bool
hasThreshold() → bool
hasUniquenessExpectation() → bool
isInitialized() → bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() → String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() → String
Returns a String representation of this message.
inherited
whichRuleType() → DataQualityRule_RuleType
writeToBuffer() → Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() → String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() → Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited