DataScan class

Represents a user-visible job which provides the insights for the related data source.

For example:

  • Data Quality: generates queries based on the rules and runs against the data to get data quality check results.
  • Data Profile: analyzes the data in table(s) and generates insights about the structure, content and relationships (such as null percent, cardinality, min/max/mean, etc).

Constructors

DataScan({String? name, String? uid, String? description, String? displayName, Map<String, String>? labels, State? state, Timestamp? createTime, Timestamp? updateTime, DataSource? data, DataScan_ExecutionSpec? executionSpec, DataScan_ExecutionStatus? executionStatus, DataScanType? type, DataQualitySpec? dataQualitySpec, DataProfileSpec? dataProfileSpec, DataQualityResult? dataQualityResult, DataProfileResult? dataProfileResult})
factory
DataScan.fromBuffer(List<int> i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory
DataScan.fromJson(String i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory

Properties

createTime ↔ Timestamp
Output only. The time when the scan was created.
getter/setter pair
data ↔ DataSource
Required. The data source for DataScan.
getter/setter pair
dataProfileResult ↔ DataProfileResult
Output only. The result of the data profile scan.
getter/setter pair
dataProfileSpec ↔ DataProfileSpec
DataProfileScan related setting.
getter/setter pair
dataQualityResult ↔ DataQualityResult
Output only. The result of the data quality scan.
getter/setter pair
dataQualitySpec ↔ DataQualitySpec
DataQualityScan related setting.
getter/setter pair
description ↔ String
Optional. Description of the scan.
getter/setter pair
displayName ↔ String
Optional. User friendly display name.
getter/setter pair
executionSpec ↔ DataScan_ExecutionSpec
Optional. DataScan execution settings.
getter/setter pair
executionStatus ↔ DataScan_ExecutionStatus
Output only. Status of the data scan execution.
getter/setter pair
hashCode → int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
info_ → BuilderInfo
no setter
isFrozen → bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
labels → Map<String, String>
Optional. User-defined labels for the scan.
no setter
name ↔ String
Output only. The relative resource name of the scan, of the form: projects/{project}/locations/{location_id}/dataScans/{datascan_id}, where project refers to a project_id or project_number and location_id refers to a GCP region.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ State
Output only. Current state of the DataScan.
getter/setter pair
type ↔ DataScanType
Output only. The type of DataScan.
getter/setter pair
uid ↔ String
Output only. System generated globally unique ID for the scan. This ID will be different if the scan is deleted and re-created with the same name.
getter/setter pair
unknownFields → UnknownFieldSet
no setterinherited
updateTime ↔ Timestamp
Output only. The time when the scan was last updated.
getter/setter pair

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearCreateTime() → void
clearData() → void
clearDataProfileResult() → void
clearDataProfileSpec() → void
clearDataQualityResult() → void
clearDataQualitySpec() → void
clearDescription() → void
clearDisplayName() → void
clearExecutionSpec() → void
clearExecutionStatus() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearName() → void
clearResult() → void
clearSpec() → void
clearState() → void
clearType() → void
clearUid() → void
clearUpdateTime() → void
clone() → DataScan
Creates a deep copy of the fields in this message. (The generated code uses mergeFromMessage.)
copyWith(void updates(DataScan)) → DataScan
Apply updates to a copy of this message.
createEmptyInstance() → DataScan
Creates an empty instance of the same message type as this.
ensureCreateTime() → Timestamp
ensureData() → DataSource
ensureDataProfileResult() → DataProfileResult
ensureDataProfileSpec() → DataProfileSpec
ensureDataQualityResult() → DataQualityResult
ensureDataQualitySpec() → DataQualitySpec
ensureExecutionSpec() → DataScan_ExecutionSpec
ensureExecutionStatus() → DataScan_ExecutionStatus
ensureUpdateTime() → Timestamp
extensionsAreInitialized() → bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) → int?
inherited
hasCreateTime() → bool
hasData() → bool
hasDataProfileResult() → bool
hasDataProfileSpec() → bool
hasDataQualityResult() → bool
hasDataQualitySpec() → bool
hasDescription() → bool
hasDisplayName() → bool
hasExecutionSpec() → bool
hasExecutionStatus() → bool
hasExtension(Extension extension) → bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) → bool
Whether this message has a field associated with tagNumber.
inherited
hasName() → bool
hasRequiredFields() → bool
Whether the message has required fields.
inherited
hasState() → bool
hasType() → bool
hasUid() → bool
hasUpdateTime() → bool
isInitialized() → bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() → String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() → String
Returns a String representation of this message.
inherited
whichResult() → DataScan_Result
whichSpec() → DataScan_Spec
writeToBuffer() → Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() → String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() → Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

create() → DataScan
createRepeated() → PbList<DataScan>
getDefault() → DataScan