Task class

A task represents a user-visible job.

Constructors

Task({String? name, String? uid, Timestamp? createTime, Timestamp? updateTime, String? description, String? displayName, State? state, Map<String, String>? labels, Task_TriggerSpec? triggerSpec, Task_ExecutionSpec? executionSpec, Task_ExecutionStatus? executionStatus, Task_SparkTaskConfig? spark, Task_NotebookTaskConfig? notebook})
factory
Task.fromBuffer(List<int> i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory
Task.fromJson(String i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory

Properties

createTime ↔ Timestamp
Output only. The time when the task was created.
getter/setter pair
description ↔ String
Optional. Description of the task.
getter/setter pair
displayName ↔ String
Optional. User friendly display name.
getter/setter pair
executionSpec ↔ Task_ExecutionSpec
Required. Spec related to how a task is executed.
getter/setter pair
executionStatus ↔ Task_ExecutionStatus
Output only. Status of the latest task executions.
getter/setter pair
hashCode → int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
info_ → BuilderInfo
no setter
isFrozen → bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
labels → Map<String, String>
Optional. User-defined labels for the task.
no setter
name ↔ String
Output only. The relative resource name of the task, of the form: projects/{project_number}/locations/{location_id}/lakes/{lake_id}/ tasks/{task_id}.
getter/setter pair
notebook ↔ Task_NotebookTaskConfig
Config related to running scheduled Notebooks.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spark ↔ Task_SparkTaskConfig
Config related to running custom Spark tasks.
getter/setter pair
state ↔ State
Output only. Current state of the task.
getter/setter pair
triggerSpec ↔ Task_TriggerSpec
Required. Spec related to how often and when a task should be triggered.
getter/setter pair
uid ↔ String
Output only. System generated globally unique ID for the task. This ID will be different if the task is deleted and re-created with the same name.
getter/setter pair
unknownFields → UnknownFieldSet
no setterinherited
updateTime ↔ Timestamp
Output only. The time when the task was last updated.
getter/setter pair

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearConfig() → void
clearCreateTime() → void
clearDescription() → void
clearDisplayName() → void
clearExecutionSpec() → void
clearExecutionStatus() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearName() → void
clearNotebook() → void
clearSpark() → void
clearState() → void
clearTriggerSpec() → void
clearUid() → void
clearUpdateTime() → void
clone() → Task
Creates a deep copy of the fields in this message. (The generated code uses mergeFromMessage.)
copyWith(void updates(Task)) → Task
Apply updates to a copy of this message.
createEmptyInstance() → Task
Creates an empty instance of the same message type as this.
ensureCreateTime() → Timestamp
ensureExecutionSpec() → Task_ExecutionSpec
ensureExecutionStatus() → Task_ExecutionStatus
ensureNotebook() → Task_NotebookTaskConfig
ensureSpark() → Task_SparkTaskConfig
ensureTriggerSpec() → Task_TriggerSpec
ensureUpdateTime() → Timestamp
extensionsAreInitialized() → bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) → int?
inherited
hasCreateTime() → bool
hasDescription() → bool
hasDisplayName() → bool
hasExecutionSpec() → bool
hasExecutionStatus() → bool
hasExtension(Extension extension) → bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) → bool
Whether this message has a field associated with tagNumber.
inherited
hasName() → bool
hasNotebook() → bool
hasRequiredFields() → bool
Whether the message has required fields.
inherited
hasSpark() → bool
hasState() → bool
hasTriggerSpec() → bool
hasUid() → bool
hasUpdateTime() → bool
isInitialized() → bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() → String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() → String
Returns a String representation of this message.
inherited
whichConfig() → Task_Config
writeToBuffer() → Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() → String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() → Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

create() → Task
createRepeated() → PbList<Task>
getDefault() → Task