Value class

A message that can hold any of the supported value types and associated metadata.

Constructors

Value({bool? booleanValue, Int64? integerValue, double? doubleValue, Key? keyValue, Entity? entityValue, LatLng? geoPointValue, ArrayValue? arrayValue, Timestamp? timestampValue, NullValue? nullValue, int? meaning, String? stringValue, List<int>? blobValue, bool? excludeFromIndexes})
factory
Value.fromBuffer(List<int> i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory
Value.fromJson(String i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory

Properties

arrayValue ↔ ArrayValue
An array value. Cannot contain another array value. A Value instance that sets field array_value must not set fields meaning or exclude_from_indexes.
getter/setter pair
blobValue ↔ List<int>
A blob value. May have at most 1,000,000 bytes. When exclude_from_indexes is false, may have at most 1500 bytes. In JSON requests, must be base64-encoded.
getter/setter pair
booleanValue ↔ bool
A boolean value.
getter/setter pair
doubleValue ↔ double
A double value.
getter/setter pair
entityValue ↔ Entity
An entity value.
getter/setter pair
excludeFromIndexes ↔ bool
If the value should be excluded from all indexes including those defined explicitly.
getter/setter pair
geoPointValue ↔ LatLng
A geo point value representing a point on the surface of Earth.
getter/setter pair
hashCode → int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
info_ → BuilderInfo
no setter
integerValue ↔ Int64
An integer value.
getter/setter pair
isFrozen → bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
keyValue ↔ Key
A key value.
getter/setter pair
meaning ↔ int
The meaning field should only be populated for backwards compatibility.
getter/setter pair
nullValue ↔ NullValue
A null value.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringValue ↔ String
A UTF-8 encoded string value. When exclude_from_indexes is false (it is indexed) , may have at most 1500 bytes. Otherwise, may be set to at most 1,000,000 bytes.
getter/setter pair
timestampValue ↔ Timestamp
A timestamp value. When stored in the Datastore, precise only to microseconds; any additional precision is rounded down.
getter/setter pair
unknownFields → UnknownFieldSet
no setterinherited

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearArrayValue() → void
clearBlobValue() → void
clearBooleanValue() → void
clearDoubleValue() → void
clearEntityValue() → void
clearExcludeFromIndexes() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearGeoPointValue() → void
clearIntegerValue() → void
clearKeyValue() → void
clearMeaning() → void
clearNullValue() → void
clearStringValue() → void
clearTimestampValue() → void
clearValueType() → void
clone() → Value
Creates a deep copy of the fields in this message. (The generated code uses mergeFromMessage.)
copyWith(void updates(Value)) → Value
Apply updates to a copy of this message.
createEmptyInstance() → Value
Creates an empty instance of the same message type as this.
ensureArrayValue() → ArrayValue
ensureEntityValue() → Entity
ensureGeoPointValue() → LatLng
ensureKeyValue() → Key
ensureTimestampValue() → Timestamp
extensionsAreInitialized() → bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) → int?
inherited
hasArrayValue() → bool
hasBlobValue() → bool
hasBooleanValue() → bool
hasDoubleValue() → bool
hasEntityValue() → bool
hasExcludeFromIndexes() → bool
hasExtension(Extension extension) → bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) → bool
Whether this message has a field associated with tagNumber.
inherited
hasGeoPointValue() → bool
hasIntegerValue() → bool
hasKeyValue() → bool
hasMeaning() → bool
hasNullValue() → bool
hasRequiredFields() → bool
Whether the message has required fields.
inherited
hasStringValue() → bool
hasTimestampValue() → bool
isInitialized() → bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() → String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() → String
Returns a String representation of this message.
inherited
whichValueType() → Value_ValueType
writeToBuffer() → Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() → String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() → Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

create() → Value
createRepeated() → PbList<Value>
getDefault() → Value