ConnectionProfile class

A set of reusable connection configurations to be used as a source or destination for a stream.

Constructors

ConnectionProfile({String? name, Timestamp? createTime, Timestamp? updateTime, Map<String, String>? labels, String? displayName, OracleProfile? oracleProfile, GcsProfile? gcsProfile, MysqlProfile? mysqlProfile, BigQueryProfile? bigqueryProfile, PostgresqlProfile? postgresqlProfile, StaticServiceIpConnectivity? staticServiceIpConnectivity, ForwardSshTunnelConnectivity? forwardSshConnectivity, PrivateConnectivity? privateConnectivity})
factory
ConnectionProfile.fromBuffer(List<int> i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory
ConnectionProfile.fromJson(String i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory

Properties

bigqueryProfile ↔ BigQueryProfile
BigQuery Connection Profile configuration.
getter/setter pair
createTime ↔ Timestamp
Output only. The create time of the resource.
getter/setter pair
displayName ↔ String
Required. Display name.
getter/setter pair
forwardSshConnectivity ↔ ForwardSshTunnelConnectivity
Forward SSH tunnel connectivity.
getter/setter pair
gcsProfile ↔ GcsProfile
Cloud Storage ConnectionProfile configuration.
getter/setter pair
hashCode → int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
info_ → BuilderInfo
no setter
isFrozen → bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
labels → Map<String, String>
Labels.
no setter
mysqlProfile ↔ MysqlProfile
MySQL ConnectionProfile configuration.
getter/setter pair
name ↔ String
Output only. The resource's name.
getter/setter pair
oracleProfile ↔ OracleProfile
Oracle ConnectionProfile configuration.
getter/setter pair
postgresqlProfile ↔ PostgresqlProfile
PostgreSQL Connection Profile configuration.
getter/setter pair
privateConnectivity ↔ PrivateConnectivity
Private connectivity.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
staticServiceIpConnectivity ↔ StaticServiceIpConnectivity
Static Service IP connectivity.
getter/setter pair
unknownFields → UnknownFieldSet
no setterinherited
updateTime ↔ Timestamp
Output only. The update time of the resource.
getter/setter pair

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearBigqueryProfile() → void
clearConnectivity() → void
clearCreateTime() → void
clearDisplayName() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearForwardSshConnectivity() → void
clearGcsProfile() → void
clearMysqlProfile() → void
clearName() → void
clearOracleProfile() → void
clearPostgresqlProfile() → void
clearPrivateConnectivity() → void
clearProfile() → void
clearStaticServiceIpConnectivity() → void
clearUpdateTime() → void
clone() → ConnectionProfile
Creates a deep copy of the fields in this message. (The generated code uses mergeFromMessage.)
copyWith(void updates(ConnectionProfile)) → ConnectionProfile
Apply updates to a copy of this message.
createEmptyInstance() → ConnectionProfile
Creates an empty instance of the same message type as this.
ensureBigqueryProfile() → BigQueryProfile
ensureCreateTime() → Timestamp
ensureForwardSshConnectivity() → ForwardSshTunnelConnectivity
ensureGcsProfile() → GcsProfile
ensureMysqlProfile() → MysqlProfile
ensureOracleProfile() → OracleProfile
ensurePostgresqlProfile() → PostgresqlProfile
ensurePrivateConnectivity() → PrivateConnectivity
ensureStaticServiceIpConnectivity() → StaticServiceIpConnectivity
ensureUpdateTime() → Timestamp
extensionsAreInitialized() → bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) → int?
inherited
hasBigqueryProfile() → bool
hasCreateTime() → bool
hasDisplayName() → bool
hasExtension(Extension extension) → bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) → bool
Whether this message has a field associated with tagNumber.
inherited
hasForwardSshConnectivity() → bool
hasGcsProfile() → bool
hasMysqlProfile() → bool
hasName() → bool
hasOracleProfile() → bool
hasPostgresqlProfile() → bool
hasPrivateConnectivity() → bool
hasRequiredFields() → bool
Whether the message has required fields.
inherited
hasStaticServiceIpConnectivity() → bool
hasUpdateTime() → bool
isInitialized() → bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() → String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() → String
Returns a String representation of this message.
inherited
whichConnectivity() → ConnectionProfile_Connectivity
whichProfile() → ConnectionProfile_Profile
writeToBuffer() → Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() → String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() → Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited