OracleSourceConfig class

Oracle data source configuration

Constructors

OracleSourceConfig({OracleRdbms? includeObjects, OracleRdbms? excludeObjects, int? maxConcurrentCdcTasks, OracleSourceConfig_DropLargeObjects? dropLargeObjects, OracleSourceConfig_StreamLargeObjects? streamLargeObjects})
factory
OracleSourceConfig.fromBuffer(List<int> i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory
OracleSourceConfig.fromJson(String i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory

Properties

dropLargeObjects ↔ OracleSourceConfig_DropLargeObjects
Drop large object values.
getter/setter pair
excludeObjects ↔ OracleRdbms
Oracle objects to exclude from the stream.
getter/setter pair
hashCode → int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
includeObjects ↔ OracleRdbms
Oracle objects to include in the stream.
getter/setter pair
info_ → BuilderInfo
no setter
isFrozen → bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
maxConcurrentCdcTasks ↔ int
Maximum number of concurrent CDC tasks. The number should be non negative. If not set (or set to 0), the system's default value will be used.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
streamLargeObjects ↔ OracleSourceConfig_StreamLargeObjects
Stream large object values. NOTE: This feature is currently experimental.
getter/setter pair
unknownFields → UnknownFieldSet
no setterinherited

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearDropLargeObjects() → void
clearExcludeObjects() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearIncludeObjects() → void
clearLargeObjectsHandling() → void
clearMaxConcurrentCdcTasks() → void
clearStreamLargeObjects() → void
clone() → OracleSourceConfig
Creates a deep copy of the fields in this message. (The generated code uses mergeFromMessage.)
copyWith(void updates(OracleSourceConfig)) → OracleSourceConfig
Apply updates to a copy of this message.
createEmptyInstance() → OracleSourceConfig
Creates an empty instance of the same message type as this.
ensureDropLargeObjects() → OracleSourceConfig_DropLargeObjects
ensureExcludeObjects() → OracleRdbms
ensureIncludeObjects() → OracleRdbms
ensureStreamLargeObjects() → OracleSourceConfig_StreamLargeObjects
extensionsAreInitialized() → bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) → int?
inherited
hasDropLargeObjects() → bool
hasExcludeObjects() → bool
hasExtension(Extension extension) → bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) → bool
Whether this message has a field associated with tagNumber.
inherited
hasIncludeObjects() → bool
hasMaxConcurrentCdcTasks() → bool
hasRequiredFields() → bool
Whether the message has required fields.
inherited
hasStreamLargeObjects() → bool
isInitialized() → bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() → String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() → String
Returns a String representation of this message.
inherited
whichLargeObjectsHandling() → OracleSourceConfig_LargeObjectsHandling
writeToBuffer() → Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() → String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() → Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited