Stream class

A resource representing streaming data from a source to a destination.

Constructors

Stream({String? name, Timestamp? createTime, Timestamp? updateTime, Map<String, String>? labels, String? displayName, SourceConfig? sourceConfig, DestinationConfig? destinationConfig, Stream_State? state, Iterable<Error>? errors, String? customerManagedEncryptionKey, Stream_BackfillAllStrategy? backfillAll, Stream_BackfillNoneStrategy? backfillNone})
factory
Stream.fromBuffer(List<int> i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory
Stream.fromJson(String i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory

Properties

backfillAll ↔ Stream_BackfillAllStrategy
Automatically backfill objects included in the stream source configuration. Specific objects can be excluded.
getter/setter pair
backfillNone ↔ Stream_BackfillNoneStrategy
Do not automatically backfill any objects.
getter/setter pair
createTime ↔ Timestamp
Output only. The creation time of the stream.
getter/setter pair
customerManagedEncryptionKey ↔ String
Immutable. A reference to a KMS encryption key. If provided, it will be used to encrypt the data. If left blank, data will be encrypted using an internal Stream-specific encryption key provisioned through KMS.
getter/setter pair
destinationConfig ↔ DestinationConfig
Required. Destination connection profile configuration.
getter/setter pair
displayName ↔ String
Required. Display name.
getter/setter pair
errors → List<Error>
Output only. Errors on the Stream.
no setter
hashCode → int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
info_ → BuilderInfo
no setter
isFrozen → bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
labels → Map<String, String>
Labels.
no setter
name ↔ String
Output only. The stream's name.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceConfig ↔ SourceConfig
Required. Source connection profile configuration.
getter/setter pair
state ↔ Stream_State
The state of the stream.
getter/setter pair
unknownFields → UnknownFieldSet
no setterinherited
updateTime ↔ Timestamp
Output only. The last update time of the stream.
getter/setter pair

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearBackfillAll() → void
clearBackfillNone() → void
clearBackfillStrategy() → void
clearCreateTime() → void
clearCustomerManagedEncryptionKey() → void
clearDestinationConfig() → void
clearDisplayName() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearName() → void
clearSourceConfig() → void
clearState() → void
clearUpdateTime() → void
clone() → Stream
Creates a deep copy of the fields in this message. (The generated code uses mergeFromMessage.)
copyWith(void updates(Stream)) → Stream
Apply updates to a copy of this message.
createEmptyInstance() → Stream
Creates an empty instance of the same message type as this.
ensureBackfillAll() → Stream_BackfillAllStrategy
ensureBackfillNone() → Stream_BackfillNoneStrategy
ensureCreateTime() → Timestamp
ensureDestinationConfig() → DestinationConfig
ensureSourceConfig() → SourceConfig
ensureUpdateTime() → Timestamp
extensionsAreInitialized() → bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) → int?
inherited
hasBackfillAll() → bool
hasBackfillNone() → bool
hasCreateTime() → bool
hasCustomerManagedEncryptionKey() → bool
hasDestinationConfig() → bool
hasDisplayName() → bool
hasExtension(Extension extension) → bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) → bool
Whether this message has a field associated with tagNumber.
inherited
hasName() → bool
hasRequiredFields() → bool
Whether the message has required fields.
inherited
hasSourceConfig() → bool
hasState() → bool
hasUpdateTime() → bool
isInitialized() → bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() → String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() → String
Returns a String representation of this message.
inherited
whichBackfillStrategy() → Stream_BackfillStrategy
writeToBuffer() → Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() → String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() → Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

create() → Stream
createRepeated() → PbList<Stream>
getDefault() → Stream