channel property
Optional. The name of the channel associated with the trigger in
projects/{project}/locations/{location}/channels/{channel} format.
You must provide a channel to receive events from Eventarc SaaS partners.
Implementation
@$pb.TagNumber(13)
$core.String get channel => $_getSZ(9);
Implementation
@$pb.TagNumber(13)
set channel($core.String v) {
$_setString(9, v);
}