ServiceConnectionMap class

The ServiceConnectionMap resource. Next id: 14

Constructors

ServiceConnectionMap({String? name, Timestamp? createTime, Timestamp? updateTime, Map<String, String>? labels, String? description, String? serviceClass, Infrastructure? infrastructure, Iterable<ServiceConnectionMap_ProducerPscConfig>? producerPscConfigs, Iterable<ServiceConnectionMap_ConsumerPscConfig>? consumerPscConfigs, Iterable<ServiceConnectionMap_ConsumerPscConnection>? consumerPscConnections, String? serviceClassUri})
factory
ServiceConnectionMap.fromBuffer(List<int> i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory
ServiceConnectionMap.fromJson(String i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory

Properties

consumerPscConfigs → List<ServiceConnectionMap_ConsumerPscConfig>
The PSC configurations on consumer side.
no setter
consumerPscConnections → List<ServiceConnectionMap_ConsumerPscConnection>
Output only. PSC connection details on consumer side.
no setter
createTime ↔ Timestamp
Output only. Time when the ServiceConnectionMap was created.
getter/setter pair
description ↔ String
A description of this resource.
getter/setter pair
hashCode → int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
info_ → BuilderInfo
no setter
infrastructure ↔ Infrastructure
Output only. The infrastructure used for connections between consumers/producers.
getter/setter pair
isFrozen → bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
labels → Map<String, String>
User-defined labels.
no setter
name ↔ String
Immutable. The name of a ServiceConnectionMap. Format: projects/{project}/locations/{location}/serviceConnectionMaps/{service_connection_map} See: https://google.aip.dev/122#fields-representing-resource-names
getter/setter pair
producerPscConfigs → List<ServiceConnectionMap_ProducerPscConfig>
The PSC configurations on producer side.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceClass ↔ String
The service class identifier this ServiceConnectionMap is for. The user of ServiceConnectionMap create API needs to have networkconnecitivty.serviceclasses.use iam permission for the service class.
getter/setter pair
serviceClassUri ↔ String
Output only. The service class uri this ServiceConnectionMap is for.
getter/setter pair
unknownFields → UnknownFieldSet
no setterinherited
updateTime ↔ Timestamp
Output only. Time when the ServiceConnectionMap was updated.
getter/setter pair

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearCreateTime() → void
clearDescription() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearInfrastructure() → void
clearName() → void
clearServiceClass() → void
clearServiceClassUri() → void
clearUpdateTime() → void
clone() → ServiceConnectionMap
Creates a deep copy of the fields in this message. (The generated code uses mergeFromMessage.)
copyWith(void updates(ServiceConnectionMap)) → ServiceConnectionMap
Apply updates to a copy of this message.
createEmptyInstance() → ServiceConnectionMap
Creates an empty instance of the same message type as this.
ensureCreateTime() → Timestamp
ensureUpdateTime() → Timestamp
extensionsAreInitialized() → bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) → int?
inherited
hasCreateTime() → bool
hasDescription() → bool
hasExtension(Extension extension) → bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) → bool
Whether this message has a field associated with tagNumber.
inherited
hasInfrastructure() → bool
hasName() → bool
hasRequiredFields() → bool
Whether the message has required fields.
inherited
hasServiceClass() → bool
hasServiceClassUri() → bool
hasUpdateTime() → bool
isInitialized() → bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() → String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() → String
Returns a String representation of this message.
inherited
writeToBuffer() → Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() → String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() → Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited