ServiceConnectionMap_ConsumerPscConnection class

PSC connection details on consumer side.

Constructors

ServiceConnectionMap_ConsumerPscConnection({String? serviceAttachmentUri, ServiceConnectionMap_ConsumerPscConnection_State? state, String? project, String? network, String? pscConnectionId, String? ip, ConnectionErrorType? errorType, Status? error, String? gceOperation, String? forwardingRule})
factory
ServiceConnectionMap_ConsumerPscConnection.fromBuffer(List<int> i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory
ServiceConnectionMap_ConsumerPscConnection.fromJson(String i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory

Properties

error ↔ Status
The most recent error during operating this connection.
getter/setter pair
errorType ↔ ConnectionErrorType
The error type indicates whether the error is consumer facing, producer facing or system internal.
getter/setter pair
forwardingRule ↔ String
The URI of the consumer forwarding rule created. Example: projects/{projectNumOrId}/regions/us-east1/networks/{resourceId}.
getter/setter pair
gceOperation ↔ String
The last Compute Engine operation to setup PSC connection.
getter/setter pair
hashCode → int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
info_ → BuilderInfo
no setter
ip ↔ String
The IP literal allocated on the consumer network for the PSC forwarding rule that is created to connect to the producer service attachment in this service connection map.
getter/setter pair
isFrozen → bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
network ↔ String
The consumer network whose PSC forwarding rule is connected to the service attachments in this service connection map. Note that the network could be on a different project (shared VPC).
getter/setter pair
project ↔ String
The consumer project whose PSC forwarding rule is connected to the service attachments in this service connection map.
getter/setter pair
pscConnectionId ↔ String
The PSC connection id of the PSC forwarding rule connected to the service attachments in this service connection map.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceAttachmentUri ↔ String
The URI of a service attachment which is the target of the PSC connection.
getter/setter pair
state ↔ ServiceConnectionMap_ConsumerPscConnection_State
The state of the PSC connection.
getter/setter pair
unknownFields → UnknownFieldSet
no setterinherited

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearError() → void
clearErrorType() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearForwardingRule() → void
clearGceOperation() → void
clearIp() → void
clearNetwork() → void
clearProject() → void
clearPscConnectionId() → void
clearServiceAttachmentUri() → void
clearState() → void
clone() → ServiceConnectionMap_ConsumerPscConnection
Creates a deep copy of the fields in this message. (The generated code uses mergeFromMessage.)
copyWith(void updates(ServiceConnectionMap_ConsumerPscConnection)) → ServiceConnectionMap_ConsumerPscConnection
Apply updates to a copy of this message.
createEmptyInstance() → ServiceConnectionMap_ConsumerPscConnection
Creates an empty instance of the same message type as this.
ensureError() → Status
extensionsAreInitialized() → bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) → int?
inherited
hasError() → bool
hasErrorType() → bool
hasExtension(Extension extension) → bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) → bool
Whether this message has a field associated with tagNumber.
inherited
hasForwardingRule() → bool
hasGceOperation() → bool
hasIp() → bool
hasNetwork() → bool
hasProject() → bool
hasPscConnectionId() → bool
hasRequiredFields() → bool
Whether the message has required fields.
inherited
hasServiceAttachmentUri() → bool
hasState() → bool
isInitialized() → bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() → String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() → String
Returns a String representation of this message.
inherited
writeToBuffer() → Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() → String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() → Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited