pathPrefixRewrite property
Prior to forwarding the request to the selected destination, the matching portion of the requests path is replaced by this value.
Implementation
@$pb.TagNumber(1)
$core.String get pathPrefixRewrite => $_getSZ(0);
Implementation
@$pb.TagNumber(1)
set pathPrefixRewrite($core.String v) {
$_setString(0, v);
}