Instance_UpgradeHistoryEntry class

The entry of VM image upgrade history.

Constructors

Instance_UpgradeHistoryEntry({String? snapshot, String? vmImage, String? containerImage, String? framework, String? version, Instance_UpgradeHistoryEntry_State? state, Timestamp? createTime, String? targetImage, Instance_UpgradeHistoryEntry_Action? action, String? targetVersion})
factory
Instance_UpgradeHistoryEntry.fromBuffer(List<int> i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory
Instance_UpgradeHistoryEntry.fromJson(String i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory

Properties

action ↔ Instance_UpgradeHistoryEntry_Action
Action. Rolloback or Upgrade.
getter/setter pair
containerImage ↔ String
The container image before this instance upgrade.
getter/setter pair
createTime ↔ Timestamp
The time that this instance upgrade history entry is created.
getter/setter pair
framework ↔ String
The framework of this notebook instance.
getter/setter pair
hashCode → int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
info_ → BuilderInfo
no setter
isFrozen → bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
snapshot ↔ String
The snapshot of the boot disk of this notebook instance before upgrade.
getter/setter pair
state ↔ Instance_UpgradeHistoryEntry_State
The state of this instance upgrade history entry.
getter/setter pair
targetImage ↔ String
Target VM Image. Format: ainotebooks-vm/project/image-name/name.
getter/setter pair
targetVersion ↔ String
Target VM Version, like m63.
getter/setter pair
unknownFields → UnknownFieldSet
no setterinherited
version ↔ String
The version of the notebook instance before this upgrade.
getter/setter pair
vmImage ↔ String
The VM image before this instance upgrade.
getter/setter pair

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearAction() → void
clearContainerImage() → void
clearCreateTime() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearFramework() → void
clearSnapshot() → void
clearState() → void
clearTargetImage() → void
clearTargetVersion() → void
clearVersion() → void
clearVmImage() → void
clone() → Instance_UpgradeHistoryEntry
Creates a deep copy of the fields in this message. (The generated code uses mergeFromMessage.)
copyWith(void updates(Instance_UpgradeHistoryEntry)) → Instance_UpgradeHistoryEntry
Apply updates to a copy of this message.
createEmptyInstance() → Instance_UpgradeHistoryEntry
Creates an empty instance of the same message type as this.
ensureCreateTime() → Timestamp
extensionsAreInitialized() → bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) → int?
inherited
hasAction() → bool
hasContainerImage() → bool
hasCreateTime() → bool
hasExtension(Extension extension) → bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) → bool
Whether this message has a field associated with tagNumber.
inherited
hasFramework() → bool
hasRequiredFields() → bool
Whether the message has required fields.
inherited
hasSnapshot() → bool
hasState() → bool
hasTargetImage() → bool
hasTargetVersion() → bool
hasVersion() → bool
hasVmImage() → bool
isInitialized() → bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() → String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() → String
Returns a String representation of this message.
inherited
writeToBuffer() → Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() → String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() → Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited