Runtime class

The definition of a Runtime for a managed notebook instance.

Constructors

Runtime({String? name, VirtualMachine? virtualMachine, Runtime_State? state, Runtime_HealthState? healthState, RuntimeAccessConfig? accessConfig, RuntimeSoftwareConfig? softwareConfig, RuntimeMetrics? metrics, Timestamp? createTime, Timestamp? updateTime, Map<String, String>? labels})
factory
Runtime.fromBuffer(List<int> i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory
Runtime.fromJson(String i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory

Properties

accessConfig ↔ RuntimeAccessConfig
The config settings for accessing runtime.
getter/setter pair
createTime ↔ Timestamp
Output only. Runtime creation time.
getter/setter pair
hashCode → int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
healthState ↔ Runtime_HealthState
Output only. Runtime health_state.
getter/setter pair
info_ → BuilderInfo
no setter
isFrozen → bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
labels → Map<String, String>
Optional. The labels to associate with this Managed Notebook or Runtime. Label keys must contain 1 to 63 characters, and must conform to RFC 1035. Label values may be empty, but, if present, must contain 1 to 63 characters, and must conform to RFC 1035. No more than 32 labels can be associated with a cluster.
no setter
metrics ↔ RuntimeMetrics
Output only. Contains Runtime daemon metrics such as Service status and JupyterLab stats.
getter/setter pair
name ↔ String
Output only. The resource name of the runtime. Format: projects/{project}/locations/{location}/runtimes/{runtimeId}
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
softwareConfig ↔ RuntimeSoftwareConfig
The config settings for software inside the runtime.
getter/setter pair
state ↔ Runtime_State
Output only. Runtime state.
getter/setter pair
unknownFields → UnknownFieldSet
no setterinherited
updateTime ↔ Timestamp
Output only. Runtime update time.
getter/setter pair
virtualMachine ↔ VirtualMachine
Use a Compute Engine VM image to start the managed notebook instance.
getter/setter pair

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearAccessConfig() → void
clearCreateTime() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearHealthState() → void
clearMetrics() → void
clearName() → void
clearRuntimeType() → void
clearSoftwareConfig() → void
clearState() → void
clearUpdateTime() → void
clearVirtualMachine() → void
clone() → Runtime
Creates a deep copy of the fields in this message. (The generated code uses mergeFromMessage.)
copyWith(void updates(Runtime)) → Runtime
Apply updates to a copy of this message.
createEmptyInstance() → Runtime
Creates an empty instance of the same message type as this.
ensureAccessConfig() → RuntimeAccessConfig
ensureCreateTime() → Timestamp
ensureMetrics() → RuntimeMetrics
ensureSoftwareConfig() → RuntimeSoftwareConfig
ensureUpdateTime() → Timestamp
ensureVirtualMachine() → VirtualMachine
extensionsAreInitialized() → bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) → int?
inherited
hasAccessConfig() → bool
hasCreateTime() → bool
hasExtension(Extension extension) → bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) → bool
Whether this message has a field associated with tagNumber.
inherited
hasHealthState() → bool
hasMetrics() → bool
hasName() → bool
hasRequiredFields() → bool
Whether the message has required fields.
inherited
hasSoftwareConfig() → bool
hasState() → bool
hasUpdateTime() → bool
hasVirtualMachine() → bool
isInitialized() → bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() → String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() → String
Returns a String representation of this message.
inherited
whichRuntimeType() → Runtime_RuntimeType
writeToBuffer() → Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() → String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() → Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

create() → Runtime
createRepeated() → PbList<Runtime>
getDefault() → Runtime