StorageObjectData class

An object within Google Cloud Storage.

Constructors

StorageObjectData({String? contentEncoding, String? contentDisposition, String? cacheControl, String? contentLanguage, Int64? metageneration, Timestamp? timeDeleted, String? contentType, Int64? size, Timestamp? timeCreated, String? crc32c, int? componentCount, String? md5Hash, String? etag, Timestamp? updated, String? storageClass, String? kmsKeyName, Timestamp? timeStorageClassUpdated, bool? temporaryHold, Timestamp? retentionExpirationTime, Map<String, String>? metadata, String? name, String? id, String? bucket, Int64? generation, StorageObjectData_CustomerEncryption? customerEncryption, bool? eventBasedHold, String? mediaLink, String? selfLink, String? kind})
factory
StorageObjectData.fromBuffer(List<int> i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory
StorageObjectData.fromJson(String i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory

Properties

bucket ↔ String
The name of the bucket containing this object.
getter/setter pair
cacheControl ↔ String
Cache-Control directive for the object data, matching RFC 7234 5.2.
getter/setter pair
componentCount ↔ int
Number of underlying components that make up this object. Components are accumulated by compose operations. Attempting to set this field will result in an error.
getter/setter pair
contentDisposition ↔ String
Content-Disposition of the object data, matching RFC 6266.
getter/setter pair
contentEncoding ↔ String
Content-Encoding of the object data, matching RFC 7231 3.1.2.2
getter/setter pair
contentLanguage ↔ String
Content-Language of the object data, matching RFC 7231 3.1.3.2.
getter/setter pair
contentType ↔ String
Content-Type of the object data, matching RFC 7231 3.1.1.5. If an object is stored without a Content-Type, it is served as application/octet-stream.
getter/setter pair
crc32c ↔ String
CRC32c checksum. For more information about using the CRC32c checksum, see Hashes and ETags: Best Practices.
getter/setter pair
customerEncryption ↔ StorageObjectData_CustomerEncryption
Metadata of customer-supplied encryption key, if the object is encrypted by such a key.
getter/setter pair
etag ↔ String
HTTP 1.1 Entity tag for the object. See RFC 7232 2.3.
getter/setter pair
eventBasedHold ↔ bool
Whether an object is under event-based hold.
getter/setter pair
generation ↔ Int64
The content generation of this object. Used for object versioning. Attempting to set this field will result in an error.
getter/setter pair
hashCode → int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
id ↔ String
The ID of the object, including the bucket name, object name, and generation number.
getter/setter pair
info_ → BuilderInfo
no setter
isFrozen → bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
kind ↔ String
The kind of item this is. For objects, this is always "storage#object".
getter/setter pair
kmsKeyName ↔ String
Cloud KMS Key used to encrypt this object, if the object is encrypted by such a key.
getter/setter pair
md5Hash ↔ String
MD5 hash of the data; encoded using base64 as per RFC 4648 4. For more information about using the MD5 hash, see Hashes and ETags: Best Practices.
getter/setter pair
Media download link.
getter/setter pair
metadata → Map<String, String>
User-provided metadata, in key/value pairs.
no setter
metageneration ↔ Int64
The version of the metadata for this object at this generation. Used for preconditions and for detecting changes in metadata. A metageneration number is only meaningful in the context of a particular generation of a particular object.
getter/setter pair
name ↔ String
The name of the object.
getter/setter pair
retentionExpirationTime ↔ Timestamp
A server-determined value that specifies the earliest time that the object's retention period expires.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
The link to this object.
getter/setter pair
size ↔ Int64
Content-Length of the object data in bytes, matching RFC 7230 3.3.2.
getter/setter pair
storageClass ↔ String
Storage class of the object.
getter/setter pair
temporaryHold ↔ bool
Whether an object is under temporary hold.
getter/setter pair
timeCreated ↔ Timestamp
The creation time of the object. Attempting to set this field will result in an error.
getter/setter pair
timeDeleted ↔ Timestamp
The deletion time of the object. Will be returned if and only if this version of the object has been deleted.
getter/setter pair
timeStorageClassUpdated ↔ Timestamp
The time at which the object's storage class was last changed.
getter/setter pair
unknownFields → UnknownFieldSet
no setterinherited
updated ↔ Timestamp
The modification time of the object metadata.
getter/setter pair

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearBucket() → void
clearCacheControl() → void
clearComponentCount() → void
clearContentDisposition() → void
clearContentEncoding() → void
clearContentLanguage() → void
clearContentType() → void
clearCrc32c() → void
clearCustomerEncryption() → void
clearEtag() → void
clearEventBasedHold() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearGeneration() → void
clearId() → void
clearKind() → void
clearKmsKeyName() → void
clearMd5Hash() → void
clearMetageneration() → void
clearName() → void
clearRetentionExpirationTime() → void
clearSize() → void
clearStorageClass() → void
clearTemporaryHold() → void
clearTimeCreated() → void
clearTimeDeleted() → void
clearTimeStorageClassUpdated() → void
clearUpdated() → void
clone() → StorageObjectData
Creates a deep copy of the fields in this message. (The generated code uses mergeFromMessage.)
copyWith(void updates(StorageObjectData)) → StorageObjectData
Apply updates to a copy of this message.
createEmptyInstance() → StorageObjectData
Creates an empty instance of the same message type as this.
ensureCustomerEncryption() → StorageObjectData_CustomerEncryption
ensureRetentionExpirationTime() → Timestamp
ensureTimeCreated() → Timestamp
ensureTimeDeleted() → Timestamp
ensureTimeStorageClassUpdated() → Timestamp
ensureUpdated() → Timestamp
extensionsAreInitialized() → bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) → int?
inherited
hasBucket() → bool
hasCacheControl() → bool
hasComponentCount() → bool
hasContentDisposition() → bool
hasContentEncoding() → bool
hasContentLanguage() → bool
hasContentType() → bool
hasCrc32c() → bool
hasCustomerEncryption() → bool
hasEtag() → bool
hasEventBasedHold() → bool
hasExtension(Extension extension) → bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) → bool
Whether this message has a field associated with tagNumber.
inherited
hasGeneration() → bool
hasId() → bool
hasKind() → bool
hasKmsKeyName() → bool
hasMd5Hash() → bool
hasMetageneration() → bool
hasName() → bool
hasRequiredFields() → bool
Whether the message has required fields.
inherited
hasRetentionExpirationTime() → bool
hasSize() → bool
hasStorageClass() → bool
hasTemporaryHold() → bool
hasTimeCreated() → bool
hasTimeDeleted() → bool
hasTimeStorageClassUpdated() → bool
hasUpdated() → bool
isInitialized() → bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() → String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() → String
Returns a String representation of this message.
inherited
writeToBuffer() → Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() → String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() → Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited