Job class

Transcoding job resource.

Constructors

Job({String? name, JobConfig? config, Job_ProcessingState? state, Timestamp? createTime, Timestamp? startTime, Timestamp? endTime, int? ttlAfterCompletionDays, Map<String, String>? labels, Status? error, Job_ProcessingMode? mode})
factory
Job.fromBuffer(List<int> i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory
Job.fromJson(String i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory

Properties

config ↔ JobConfig
The configuration for this job.
getter/setter pair
createTime ↔ Timestamp
Output only. The time the job was created.
getter/setter pair
endTime ↔ Timestamp
Output only. The time the transcoding finished.
getter/setter pair
error ↔ Status
Output only. An error object that describes the reason for the failure. This property is always present when state is FAILED.
getter/setter pair
hashCode → int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
info_ → BuilderInfo
no setter
isFrozen → bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
labels → Map<String, String>
The labels associated with this job. You can use these to organize and group your jobs.
no setter
mode ↔ Job_ProcessingMode
The processing mode of the job. The default is PROCESSING_MODE_INTERACTIVE.
getter/setter pair
name ↔ String
The resource name of the job. Format: projects/{project_number}/locations/{location}/jobs/{job}
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime ↔ Timestamp
Output only. The time the transcoding started.
getter/setter pair
state ↔ Job_ProcessingState
Output only. The current state of the job.
getter/setter pair
ttlAfterCompletionDays ↔ int
Job time to live value in days, which will be effective after job completion. Job should be deleted automatically after the given TTL. Enter a value between 1 and 90. The default is 30.
getter/setter pair
unknownFields → UnknownFieldSet
no setterinherited

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearConfig() → void
clearCreateTime() → void
clearEndTime() → void
clearError() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearJobConfig() → void
clearMode() → void
clearName() → void
clearStartTime() → void
clearState() → void
clearTtlAfterCompletionDays() → void
clone() → Job
Creates a deep copy of the fields in this message. (The generated code uses mergeFromMessage.)
copyWith(void updates(Job)) → Job
Apply updates to a copy of this message.
createEmptyInstance() → Job
Creates an empty instance of the same message type as this.
ensureConfig() → JobConfig
ensureCreateTime() → Timestamp
ensureEndTime() → Timestamp
ensureError() → Status
ensureStartTime() → Timestamp
extensionsAreInitialized() → bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) → int?
inherited
hasConfig() → bool
hasCreateTime() → bool
hasEndTime() → bool
hasError() → bool
hasExtension(Extension extension) → bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) → bool
Whether this message has a field associated with tagNumber.
inherited
hasMode() → bool
hasName() → bool
hasRequiredFields() → bool
Whether the message has required fields.
inherited
hasStartTime() → bool
hasState() → bool
hasTtlAfterCompletionDays() → bool
isInitialized() → bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() → String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() → String
Returns a String representation of this message.
inherited
whichJobConfig() → Job_JobConfig
writeToBuffer() → Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() → String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() → Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

create() → Job
createRepeated() → PbList<Job>
getDefault() → Job