Process class

Message describing the Process object.

Constructors

Process({String? name, Timestamp? createTime, Timestamp? updateTime, String? analysis, Iterable<String>? attributeOverrides, RunStatus? runStatus, RunMode? runMode, String? eventId, String? batchId, int? retryCount})
factory
Process.fromBuffer(List<int> i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory
Process.fromJson(String i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory

Properties

analysis ↔ String
Required. Reference to an existing Analysis resource.
getter/setter pair
attributeOverrides → List<String>
Optional. Attribute overrides of the Analyzers. Format for each single override item: "{analyzer_name}:{attribute_key}={value}"
no setter
batchId ↔ String
Optional. Optional: Batch ID of the Process.
getter/setter pair
createTime ↔ Timestamp
Output only. The create timestamp.
getter/setter pair
eventId ↔ String
Optional. Event ID of the input/output streams. This is useful when you have a StreamSource/StreamSink operator in the Analysis, and you want to manually specify the Event to read from/write to.
getter/setter pair
hashCode → int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
info_ → BuilderInfo
no setter
isFrozen → bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
name ↔ String
The name of resource.
getter/setter pair
retryCount ↔ int
Optional. Optional: The number of retries for a process in submission mode the system should try before declaring failure. By default, no retry will be performed.
getter/setter pair
runMode ↔ RunMode
Optional. Run mode of the Process.
getter/setter pair
runStatus ↔ RunStatus
Optional. Status of the Process.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unknownFields → UnknownFieldSet
no setterinherited
updateTime ↔ Timestamp
Output only. The update timestamp.
getter/setter pair

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearAnalysis() → void
clearBatchId() → void
clearCreateTime() → void
clearEventId() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearName() → void
clearRetryCount() → void
clearRunMode() → void
clearRunStatus() → void
clearUpdateTime() → void
clone() → Process
Creates a deep copy of the fields in this message. (The generated code uses mergeFromMessage.)
copyWith(void updates(Process)) → Process
Apply updates to a copy of this message.
createEmptyInstance() → Process
Creates an empty instance of the same message type as this.
ensureCreateTime() → Timestamp
ensureRunStatus() → RunStatus
ensureUpdateTime() → Timestamp
extensionsAreInitialized() → bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) → int?
inherited
hasAnalysis() → bool
hasBatchId() → bool
hasCreateTime() → bool
hasEventId() → bool
hasExtension(Extension extension) → bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) → bool
Whether this message has a field associated with tagNumber.
inherited
hasName() → bool
hasRequiredFields() → bool
Whether the message has required fields.
inherited
hasRetryCount() → bool
hasRunMode() → bool
hasRunStatus() → bool
hasUpdateTime() → bool
isInitialized() → bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() → String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() → String
Returns a String representation of this message.
inherited
writeToBuffer() → Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() → String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() → Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

create() → Process
createRepeated() → PbList<Process>
getDefault() → Process