ProcessorConfig class

Next ID: 29

Constructors

ProcessorConfig({VideoStreamInputConfig? videoStreamInputConfig, MediaWarehouseConfig? mediaWarehouseConfig, PersonBlurConfig? personBlurConfig, OccupancyCountConfig? occupancyCountConfig, VertexAutoMLVisionConfig? vertexAutomlVisionConfig, VertexAutoMLVideoConfig? vertexAutomlVideoConfig, PersonVehicleDetectionConfig? personVehicleDetectionConfig, VertexCustomConfig? vertexCustomConfig, GeneralObjectDetectionConfig? generalObjectDetectionConfig, BigQueryConfig? bigQueryConfig, AIEnabledDevicesInputConfig? aiEnabledDevicesInputConfig, PersonalProtectiveEquipmentDetectionConfig? personalProtectiveEquipmentDetectionConfig})
factory
ProcessorConfig.fromBuffer(List<int> i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory
ProcessorConfig.fromJson(String i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory

Properties

aiEnabledDevicesInputConfig ↔ AIEnabledDevicesInputConfig
Config of AI-enabled input devices.
getter/setter pair
bigQueryConfig ↔ BigQueryConfig
Configs of BigQuery processor.
getter/setter pair
generalObjectDetectionConfig ↔ GeneralObjectDetectionConfig
Configs of General Object Detection processor.
getter/setter pair
hashCode → int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
info_ → BuilderInfo
no setter
isFrozen → bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
mediaWarehouseConfig ↔ MediaWarehouseConfig
Configs of media warehouse processor.
getter/setter pair
occupancyCountConfig ↔ OccupancyCountConfig
Configs of occupancy count processor.
getter/setter pair
personalProtectiveEquipmentDetectionConfig ↔ PersonalProtectiveEquipmentDetectionConfig
Configs of personal_protective_equipment_detection_config
getter/setter pair
personBlurConfig ↔ PersonBlurConfig
Configs of person blur processor.
getter/setter pair
personVehicleDetectionConfig ↔ PersonVehicleDetectionConfig
Configs of Person Vehicle Detection processor.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unknownFields → UnknownFieldSet
no setterinherited
vertexAutomlVideoConfig ↔ VertexAutoMLVideoConfig
Configs of Vertex AutoML video processor.
getter/setter pair
vertexAutomlVisionConfig ↔ VertexAutoMLVisionConfig
Configs of Vertex AutoML vision processor.
getter/setter pair
vertexCustomConfig ↔ VertexCustomConfig
Configs of Vertex Custom processor.
getter/setter pair
videoStreamInputConfig ↔ VideoStreamInputConfig
Configs of stream input processor.
getter/setter pair

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearAiEnabledDevicesInputConfig() → void
clearBigQueryConfig() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearGeneralObjectDetectionConfig() → void
clearMediaWarehouseConfig() → void
clearOccupancyCountConfig() → void
clearPersonalProtectiveEquipmentDetectionConfig() → void
clearPersonBlurConfig() → void
clearPersonVehicleDetectionConfig() → void
clearProcessorConfig() → void
clearVertexAutomlVideoConfig() → void
clearVertexAutomlVisionConfig() → void
clearVertexCustomConfig() → void
clearVideoStreamInputConfig() → void
clone() → ProcessorConfig
Creates a deep copy of the fields in this message. (The generated code uses mergeFromMessage.)
copyWith(void updates(ProcessorConfig)) → ProcessorConfig
Apply updates to a copy of this message.
createEmptyInstance() → ProcessorConfig
Creates an empty instance of the same message type as this.
ensureAiEnabledDevicesInputConfig() → AIEnabledDevicesInputConfig
ensureBigQueryConfig() → BigQueryConfig
ensureGeneralObjectDetectionConfig() → GeneralObjectDetectionConfig
ensureMediaWarehouseConfig() → MediaWarehouseConfig
ensureOccupancyCountConfig() → OccupancyCountConfig
ensurePersonalProtectiveEquipmentDetectionConfig() → PersonalProtectiveEquipmentDetectionConfig
ensurePersonBlurConfig() → PersonBlurConfig
ensurePersonVehicleDetectionConfig() → PersonVehicleDetectionConfig
ensureVertexAutomlVideoConfig() → VertexAutoMLVideoConfig
ensureVertexAutomlVisionConfig() → VertexAutoMLVisionConfig
ensureVertexCustomConfig() → VertexCustomConfig
ensureVideoStreamInputConfig() → VideoStreamInputConfig
extensionsAreInitialized() → bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) → int?
inherited
hasAiEnabledDevicesInputConfig() → bool
hasBigQueryConfig() → bool
hasExtension(Extension extension) → bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) → bool
Whether this message has a field associated with tagNumber.
inherited
hasGeneralObjectDetectionConfig() → bool
hasMediaWarehouseConfig() → bool
hasOccupancyCountConfig() → bool
hasPersonalProtectiveEquipmentDetectionConfig() → bool
hasPersonBlurConfig() → bool
hasPersonVehicleDetectionConfig() → bool
hasRequiredFields() → bool
Whether the message has required fields.
inherited
hasVertexAutomlVideoConfig() → bool
hasVertexAutomlVisionConfig() → bool
hasVertexCustomConfig() → bool
hasVideoStreamInputConfig() → bool
isInitialized() → bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() → String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() → String
Returns a String representation of this message.
inherited
whichProcessorConfig() → ProcessorConfig_ProcessorConfig
writeToBuffer() → Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() → String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() → Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited