ComputeEngineTargetDefaults class

ComputeEngineTargetDefaults is a collection of details for creating a VM in a target Compute Engine project.

Constructors

ComputeEngineTargetDefaults({String? vmName, String? targetProject, String? zone, String? machineTypeSeries, String? machineType, Iterable<String>? networkTags, Iterable<NetworkInterface>? networkInterfaces, String? serviceAccount, ComputeEngineDiskType? diskType, Map<String, String>? labels, ComputeEngineLicenseType? licenseType, AppliedLicense? appliedLicense, ComputeScheduling? computeScheduling, bool? secureBoot, ComputeEngineBootOption? bootOption, Map<String, String>? metadata, Iterable<String>? additionalLicenses, String? hostname})
factory
ComputeEngineTargetDefaults.fromBuffer(List<int> i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory
ComputeEngineTargetDefaults.fromJson(String i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory

Properties

additionalLicenses → List<String>
Additional licenses to assign to the VM.
no setter
appliedLicense ↔ AppliedLicense
Output only. The OS license returned from the adaptation module report.
getter/setter pair
bootOption ↔ ComputeEngineBootOption
Output only. The VM Boot Option, as set in the source vm.
getter/setter pair
computeScheduling ↔ ComputeScheduling
Compute instance scheduling information (if empty default is used).
getter/setter pair
diskType ↔ ComputeEngineDiskType
The disk type to use in the VM.
getter/setter pair
hashCode → int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
hostname ↔ String
The hostname to assign to the VM.
getter/setter pair
info_ → BuilderInfo
no setter
isFrozen → bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
labels → Map<String, String>
A map of labels to associate with the VM.
no setter
licenseType ↔ ComputeEngineLicenseType
The license type to use in OS adaptation.
getter/setter pair
machineType ↔ String
The machine type to create the VM with.
getter/setter pair
machineTypeSeries ↔ String
The machine type series to create the VM with.
getter/setter pair
metadata → Map<String, String>
The metadata key/value pairs to assign to the VM.
no setter
networkInterfaces → List<NetworkInterface>
List of NICs connected to this VM.
no setter
networkTags → List<String>
A map of network tags to associate with the VM.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secureBoot ↔ bool
Defines whether the instance has Secure Boot enabled. This can be set to true only if the vm boot option is EFI.
getter/setter pair
serviceAccount ↔ String
The service account to associate the VM with.
getter/setter pair
targetProject ↔ String
The full path of the resource of type TargetProject which represents the Compute Engine project in which to create this VM.
getter/setter pair
unknownFields → UnknownFieldSet
no setterinherited
vmName ↔ String
The name of the VM to create.
getter/setter pair
zone ↔ String
The zone in which to create the VM.
getter/setter pair

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearAppliedLicense() → void
clearBootOption() → void
clearComputeScheduling() → void
clearDiskType() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearHostname() → void
clearLicenseType() → void
clearMachineType() → void
clearMachineTypeSeries() → void
clearSecureBoot() → void
clearServiceAccount() → void
clearTargetProject() → void
clearVmName() → void
clearZone() → void
clone() → ComputeEngineTargetDefaults
Creates a deep copy of the fields in this message. (The generated code uses mergeFromMessage.)
copyWith(void updates(ComputeEngineTargetDefaults)) → ComputeEngineTargetDefaults
Apply updates to a copy of this message.
createEmptyInstance() → ComputeEngineTargetDefaults
Creates an empty instance of the same message type as this.
ensureAppliedLicense() → AppliedLicense
ensureComputeScheduling() → ComputeScheduling
extensionsAreInitialized() → bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) → int?
inherited
hasAppliedLicense() → bool
hasBootOption() → bool
hasComputeScheduling() → bool
hasDiskType() → bool
hasExtension(Extension extension) → bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) → bool
Whether this message has a field associated with tagNumber.
inherited
hasHostname() → bool
hasLicenseType() → bool
hasMachineType() → bool
hasMachineTypeSeries() → bool
hasRequiredFields() → bool
Whether the message has required fields.
inherited
hasSecureBoot() → bool
hasServiceAccount() → bool
hasTargetProject() → bool
hasVmName() → bool
hasZone() → bool
isInitialized() → bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() → String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() → String
Returns a String representation of this message.
inherited
writeToBuffer() → Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() → String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() → Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited