DatacenterConnector class

DatacenterConnector message describes a connector between the Source and Google Cloud, which is installed on a vmware datacenter (an OVA vm installed by the user) to connect the Datacenter to Google Cloud and support vm migration data transfer.

Constructors

DatacenterConnector({Timestamp? createTime, Timestamp? updateTime, String? name, String? serviceAccount, String? version, DatacenterConnector_State? state, Timestamp? stateTime, String? bucket, Status? error, String? registrationId, String? applianceInfrastructureVersion, String? applianceSoftwareVersion, AvailableUpdates? availableVersions, UpgradeStatus? upgradeStatus})
factory
DatacenterConnector.fromBuffer(List<int> i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory
DatacenterConnector.fromJson(String i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory

Properties

applianceInfrastructureVersion ↔ String
Output only. Appliance OVA version. This is the OVA which is manually installed by the user and contains the infrastructure for the automatically updatable components on the appliance.
getter/setter pair
applianceSoftwareVersion ↔ String
Output only. Appliance last installed update bundle version. This is the version of the automatically updatable components on the appliance.
getter/setter pair
availableVersions ↔ AvailableUpdates
Output only. The available versions for updating this appliance.
getter/setter pair
bucket ↔ String
Output only. The communication channel between the datacenter connector and Google Cloud.
getter/setter pair
createTime ↔ Timestamp
Output only. The time the connector was created (as an API call, not when it was actually installed).
getter/setter pair
error ↔ Status
Output only. Provides details on the state of the Datacenter Connector in case of an error.
getter/setter pair
hashCode → int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
info_ → BuilderInfo
no setter
isFrozen → bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
name ↔ String
Output only. The connector's name.
getter/setter pair
registrationId ↔ String
Immutable. A unique key for this connector. This key is internal to the OVA connector and is supplied with its creation during the registration process and can not be modified.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceAccount ↔ String
The service account to use in the connector when communicating with the cloud.
getter/setter pair
state ↔ DatacenterConnector_State
Output only. State of the DatacenterConnector, as determined by the health checks.
getter/setter pair
stateTime ↔ Timestamp
Output only. The time the state was last set.
getter/setter pair
unknownFields → UnknownFieldSet
no setterinherited
updateTime ↔ Timestamp
Output only. The last time the connector was updated with an API call.
getter/setter pair
upgradeStatus ↔ UpgradeStatus
Output only. The status of the current / last upgradeAppliance operation.
getter/setter pair
version ↔ String
The version running in the DatacenterConnector. This is supplied by the OVA connector during the registration process and can not be modified.
getter/setter pair

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearApplianceInfrastructureVersion() → void
clearApplianceSoftwareVersion() → void
clearAvailableVersions() → void
clearBucket() → void
clearCreateTime() → void
clearError() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearName() → void
clearRegistrationId() → void
clearServiceAccount() → void
clearState() → void
clearStateTime() → void
clearUpdateTime() → void
clearUpgradeStatus() → void
clearVersion() → void
clone() → DatacenterConnector
Creates a deep copy of the fields in this message. (The generated code uses mergeFromMessage.)
copyWith(void updates(DatacenterConnector)) → DatacenterConnector
Apply updates to a copy of this message.
createEmptyInstance() → DatacenterConnector
Creates an empty instance of the same message type as this.
ensureAvailableVersions() → AvailableUpdates
ensureCreateTime() → Timestamp
ensureError() → Status
ensureStateTime() → Timestamp
ensureUpdateTime() → Timestamp
ensureUpgradeStatus() → UpgradeStatus
extensionsAreInitialized() → bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) → int?
inherited
hasApplianceInfrastructureVersion() → bool
hasApplianceSoftwareVersion() → bool
hasAvailableVersions() → bool
hasBucket() → bool
hasCreateTime() → bool
hasError() → bool
hasExtension(Extension extension) → bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) → bool
Whether this message has a field associated with tagNumber.
inherited
hasName() → bool
hasRegistrationId() → bool
hasRequiredFields() → bool
Whether the message has required fields.
inherited
hasServiceAccount() → bool
hasState() → bool
hasStateTime() → bool
hasUpdateTime() → bool
hasUpgradeStatus() → bool
hasVersion() → bool
isInitialized() → bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() → String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() → String
Returns a String representation of this message.
inherited
writeToBuffer() → Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() → String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() → Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited