ReplicationCycle class

ReplicationCycle contains information about the current replication cycle status.

Constructors

ReplicationCycle({Timestamp? startTime, int? progressPercent, Timestamp? endTime, Duration? totalPauseDuration, Iterable<CycleStep>? steps, int? cycleNumber, ReplicationCycle_State? state, Status? error, String? name, Iterable<MigrationWarning>? warnings})
factory
ReplicationCycle.fromBuffer(List<int> i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory
ReplicationCycle.fromJson(String i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory

Properties

cycleNumber ↔ int
The cycle's ordinal number.
getter/setter pair
endTime ↔ Timestamp
The time the replication cycle has ended.
getter/setter pair
error ↔ Status
Provides details on the state of the cycle in case of an error.
getter/setter pair
hashCode → int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
info_ → BuilderInfo
no setter
isFrozen → bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
name ↔ String
The identifier of the ReplicationCycle.
getter/setter pair
progressPercent ↔ int
The current progress in percentage of this cycle. Was replaced by 'steps' field, which breaks down the cycle progression more accurately.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime ↔ Timestamp
The time the replication cycle has started.
getter/setter pair
state ↔ ReplicationCycle_State
State of the ReplicationCycle.
getter/setter pair
steps → List<CycleStep>
The cycle's steps list representing its progress.
no setter
totalPauseDuration ↔ Duration
The accumulated duration the replication cycle was paused.
getter/setter pair
unknownFields → UnknownFieldSet
no setterinherited
warnings → List<MigrationWarning>
Output only. Warnings that occurred during the cycle.
no setter

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearCycleNumber() → void
clearEndTime() → void
clearError() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearName() → void
clearProgressPercent() → void
clearStartTime() → void
clearState() → void
clearTotalPauseDuration() → void
clone() → ReplicationCycle
Creates a deep copy of the fields in this message. (The generated code uses mergeFromMessage.)
copyWith(void updates(ReplicationCycle)) → ReplicationCycle
Apply updates to a copy of this message.
createEmptyInstance() → ReplicationCycle
Creates an empty instance of the same message type as this.
ensureEndTime() → Timestamp
ensureError() → Status
ensureStartTime() → Timestamp
ensureTotalPauseDuration() → Duration
extensionsAreInitialized() → bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) → int?
inherited
hasCycleNumber() → bool
hasEndTime() → bool
hasError() → bool
hasExtension(Extension extension) → bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) → bool
Whether this message has a field associated with tagNumber.
inherited
hasName() → bool
hasProgressPercent() → bool
hasRequiredFields() → bool
Whether the message has required fields.
inherited
hasStartTime() → bool
hasState() → bool
hasTotalPauseDuration() → bool
isInitialized() → bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() → String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() → String
Returns a String representation of this message.
inherited
writeToBuffer() → Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() → String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() → Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited