UtilizationReport class

Utilization report details the utilization (CPU, memory, etc.) of selected source VMs.

Constructors

UtilizationReport({String? name, String? displayName, UtilizationReport_State? state, Timestamp? stateTime, Status? error, Timestamp? createTime, UtilizationReport_TimeFrame? timeFrame, Timestamp? frameEndTime, int? vmCount, Iterable<VmUtilizationInfo>? vms})
factory
UtilizationReport.fromBuffer(List<int> i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory
UtilizationReport.fromJson(String i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory

Properties

createTime ↔ Timestamp
Output only. The time the report was created (this refers to the time of the request, not the time the report creation completed).
getter/setter pair
displayName ↔ String
The report display name, as assigned by the user.
getter/setter pair
error ↔ Status
Output only. Provides details on the state of the report in case of an error.
getter/setter pair
frameEndTime ↔ Timestamp
Output only. The point in time when the time frame ends. Notice that the time frame is counted backwards. For instance if the "frame_end_time" value is 2021/01/20 and the time frame is WEEK then the report covers the week between 2021/01/20 and 2021/01/14.
getter/setter pair
hashCode → int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
info_ → BuilderInfo
no setter
isFrozen → bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
name ↔ String
Output only. The report unique name.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ UtilizationReport_State
Output only. Current state of the report.
getter/setter pair
stateTime ↔ Timestamp
Output only. The time the state was last set.
getter/setter pair
timeFrame ↔ UtilizationReport_TimeFrame
Time frame of the report.
getter/setter pair
unknownFields → UnknownFieldSet
no setterinherited
vmCount ↔ int
Output only. Total number of VMs included in the report.
getter/setter pair
vms → List<VmUtilizationInfo>
List of utilization information per VM. When sent as part of the request, the "vm_id" field is used in order to specify which VMs to include in the report. In that case all other fields are ignored.
no setter

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearCreateTime() → void
clearDisplayName() → void
clearError() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearFrameEndTime() → void
clearName() → void
clearState() → void
clearStateTime() → void
clearTimeFrame() → void
clearVmCount() → void
clone() → UtilizationReport
Creates a deep copy of the fields in this message. (The generated code uses mergeFromMessage.)
copyWith(void updates(UtilizationReport)) → UtilizationReport
Apply updates to a copy of this message.
createEmptyInstance() → UtilizationReport
Creates an empty instance of the same message type as this.
ensureCreateTime() → Timestamp
ensureError() → Status
ensureFrameEndTime() → Timestamp
ensureStateTime() → Timestamp
extensionsAreInitialized() → bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) → int?
inherited
hasCreateTime() → bool
hasDisplayName() → bool
hasError() → bool
hasExtension(Extension extension) → bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) → bool
Whether this message has a field associated with tagNumber.
inherited
hasFrameEndTime() → bool
hasName() → bool
hasRequiredFields() → bool
Whether the message has required fields.
inherited
hasState() → bool
hasStateTime() → bool
hasTimeFrame() → bool
hasVmCount() → bool
isInitialized() → bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() → String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() → String
Returns a String representation of this message.
inherited
writeToBuffer() → Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() → String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() → Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited